bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 37. Aventiure
___________________________________________________ #### Auentv wie Rvdeger erslagen wart
| ### <Ez> heten die ellenden wider morgen gvot getan ### wine der Gotelinde chom ze hove gegan ### do sah er beidenthalben div vngefvgen ser ### daz weinte innechliche der <getriwe> Rvdeger
###### 2193 | ### Owe sprach der reche deich ie den lip gewan ### daz disen starchen iamer chan niemen vnderstan ### swie gern ihz vriden wolde der kvnic entvot es niht ### wander der sinen leide ie mere vn– mere geschiht
###### 2194 | ### Do sande an Dietrichen der gvte Rvdeger ### ob siz noch chunden wenden an den kvnigen her ### do enbot im der von Berne wer moht ez vnderstan ### ezn wil der kunic Ezele scheiden niemene lan
| ### Do sah ein Hvnen reche Rvdegeren stan ### mit weinenden ovgen vn– het des vil getan ### do sprach zer kvniginne nv seht ir wie er stat ### der doch gewalt den meisten bi iv vn– Ezeln hat
###### 2196 | ### vn– dem ez allez dienet livt vn– ovch div lant ### wie ist so vil der bvrge vn– der erbe an in gewant ### der er von dem kvnige so vil gehaben mac ### er geslvc in disen stvrmen noch nie <lobelichen> slac
###### 2197 | ### Mich dvnchet ern rvche wie ez hie vmbe gat ### daz et er den vollen nach sime willen hat ### man giht im er si chvener danne iemen mvge sin ### daz ist in disen sorgen worden boeseliche schin
###### 2198 | ### Mit trvrigem mvote der vil getriwer man ### den er daz reden horte der helt der blicht in an ### er daht dv solt ez arnen dv gihest ich si verzaget [79v] ### dv hast div dinen mære ze hove ze lvte gesaget
| ### Die fvost begvnder twingen do lief er in an ### er slvoc so chreftechliche den hvnischen man ### daz er im vor den fvzen lac vil schiere tot ### do was aber gemeret des kvnic Ezeln not
###### 2200 | ### Fvrder zage bose sprach do Rvdeger ### ich han doch genvoge leit vn– ser ### daz ich hie niht enstrite zwiv wizzestv mir daz ### ia wær ih den gesten grozlichen haz
###### 2201 | ### vn– allez daz ich mohte daz het ich in getan ### niwan daz ich die degene her gefvret han ### ich was ir geleitte in mines herren lan ### des ensol mit in niht striten min vil ellendes hant
###### 2202 | ### Do sprach zem marcgraven Ezel der kunec her ### wie habt ir vns geholfen vil edel Rvdeger ### wan wir so vil der veigen hie ze lande han ### wir bedorften ir niht mere ir habt vil vbele getan
###### 2203 | ### Do sprach der ritter edele da beswart er mir den mvot ### vn– hat mir verwizzen ere vn– gvot ### des ich von dinen handen habe so vil genomen ### daz ist dem lvgenære ein teil vnstætelichen chomen
| ### D Chriemh' saz bi Ezelen div het ez ovch gesehen ### daz von des rechen zorne dem Hvnen was geschehen ### si chleit iz vngefvge ir ovgen warn naz ### si sprach zvo Rvdegere wie haben wir verdienet daz
###### 2205 | ### daz ir mir un– dem kvnige meret vnser leit ### nv habt ir vns doch Rvdeger allez her geseit ### ir woldet durch vns wagen die ere vn– ovch daz leben ### ich hort iv vil der rechen den pris vil grozlichen gebn
###### 2206 | ### Ich man <ivch> der genaden vn– ir mir habt geswarn ### do ir mir zvo Ezelen her ze lande rietet varn ### daz ir mir woldet dienen an vnser eines tot ### des enwart mir armen wibe nie so grozliche not
###### 2207 | ### Daz ist ane lovgen ich swor iv edel wip ### ich wolde dvrch ivch wagen die ere vn– ovch den lip ### daz ich die sele vliese des enhan ich niht gesworn ### ia braht ich her ze lande die iwern brvder wol geborn
###### 2208 | ### Si sprach gedenche Rvdeger der grozen triwen din ### der stæte vn– ovch der eide daz dv den schaden min ### immer woldest <rechen> vn– elliv miniv leit ### des man ich dich hivte degen chvne vn– gemeit
| ### Ezele der riche vlegen ovch began ### do bvten si sich beide ze fvzen fvr den man ### den gvten marcgraven trvren man do sach ### der vil getriwe reche harte iæmerlichen sprach
###### 2210 | ### Owe mir gotes armen sprach der getriwe man ### aller miner eren der mvoz ich ab stan ### triwen vn– zvhte der got an mir gebot ### vil richer got von himele daz mihs wendet niht der tot
###### 2211 | ### Swelhez ich nv laze vn– daz ander began ### so han ich bosliche vn– vbel getan ### laz aber [80r]ih si beide mich schiltet elliv diet ### nv rvche mich bewisen der mir ze lebene geriet
###### 2212 | ### Do baten si genote der kunic vn– ovch sin wip ### des mvsen sider degene verliesen den lip ### vor Rvdegeres handen da ovch der helt erstarp ### ir mvget daz balde horen daz er vil iæmerlichen warp
###### 2213 | ### Er wiste schaden gewinnen vn– vngefvgiv leit ### er het dem kunige vil gerne verseit ### vn– ovch der kvniginne vil ser vorht er daz ### ob er ir einen slvege daz im div werlt trvge haz
###### 2214 | ### Do sprach der marcgrave Rvdeger der chvne man ### her chvnic nv nemt hin widere al daz ich von iv han ### lant vn– burge des sol mir niht besten ### ich wil vf minen fvzen in daz ellende gen
###### 2215 | ### Alles gvtes ane so rvom ich iv div lant ### min wip vn– mine tohter nim ich an mine hant ### ê daz ich ane triwe beliben mvse tot ### ich het genomen vbele iwer golt also rot
| ### Do sprach der kunic Ezele wer hvlfe danne mir ### daz lant zvo den bvrgen daz gib ich allez dir ### daz dv mich rechest Rvdeger an den vinden min ### dv solt ein kvnic gewaltech benebn mime libe sin
###### 2217 | ### Do sprach aber Rvdeger wie sol ihz ane van ### heim ze mime hvose ich si geladet han ### trinchen vn– spise ich in mit triwen bot ### vn– gab in mine gabe sol ich si dar zvo slahen tot
###### 2218 | ### Die lvte wænent lihte daz ich si verzaget ### deheinen minen dienest han ich in widersaget ### solde ich nv mit in striten daz wære missetan ### so rowe mich div frivntschaft die ich mit in geworben han
###### 2219 | ### Giselher dem degene gab ich die tohter min ### sine chvnde in dirre werlde niht baz verwendet sin ### vf zvht vn– ovch vf ere vf triwe vn– ovch vf gvot ### ine gesach nie kunec so ivngen so rehte tvgentlich gemvot
###### 2220 | ### Do sprach aber Chriemh' vil edel Rvdeger ### nv la dich erbarmen vnser beider ser ### min vn– ovch des kuniges gedenche wol dar an ### daz nie wirt deheiner so leide geste gewan
###### 2221 | ### Do sprac der marcgrave wider daz edel wip ### ez mvz noch hivte gelten der Rvdegeres lip ### swaz ir vn– ovch min herre mir liebes habt getan ### dar vmbe mvz ich sterben ez mac niht langer nv gestan
###### 2222 | ### <Ich> weiz wol daz noch hivte mine burge vn– miniv lant ### iv ledech mvzen werden von ir etesliches hant ### ich bevilhe iv vf genade min wip vn– min chint ### vn– die vil ellenden die da zen Bechelaren sint
| ### Nv lon dir got Rvdeger sprach der kunic do ### er vn– div kvniginne si wrden beidiv vro ### vns svln dine lvte vil wol bevolhen wesen ### ovch getrowe ich mime heile daz dv maht selbe wol genesen
###### 2224 | ### Do liez er an die wâge die sele vn– ovch den lip ### do begunde weinen daz [8ov]Ezeln wip ### er sprach ich wil iv leisten als ich gelobet han ### owe der minen frivnde die ich leider mvoz bestan
###### 2225 | ### Man sah in von dem kvnige in starchen riwen gen ### do sah er siner rechen ein teil da nahen sten ### er sprach ir svlt ivch wafen alle mine man ### die chvnen Burgonden mvz ich nv leider bestan
###### 2226 | ### Do brahte man den rechen ir gewæfen al zehant ### ez der helm wære vn– ovch des schildes rant ### von ir <ingesinde> wart ez in dar getragen ### sit horten leidiv mære die chvnen ellenden sagen
| ### Gewafent wart do Rvdeger mit fvnfhvndert man ### dar vber zwelf rechen ze helf er ovch gewan ### die wolden pris erwerben in des stvrmes not ### sine wisten niht der mære daz so nahte der tot
###### 2228 | ### Do sah man Rvdegere vnder helme gan ### ez trvgen swert div scharpfen des marcgraven man ### vn– dar zv vor ir handen die liehten schilde breit ### daz sach der videlære ez was im ane maze leit
###### 2229 | ### Ovch sach der ivnge Giselher sinen sweher gen ### mit vf gebvndem helme wie mohter do versten ### waz er da mite meinte niwan allez gvot ### des wart der kvnic edele von hercen vrolich gemvot
###### 2230 | ### Nv wol mich solher frivnde sprach Giselher der degn ### die wir han gewnnen her vf disen wegn ### wir svln mines wibes vil wol geniezen hie ### mir ist liep vf mine triwe daz ie der hyrat ergie
###### 2231 | ### Ine weiz wes ir ivh troestet sprach do der spileman ### wa gesaliet ir ie dvrch svne so manigen rechen gan ### mit vf gebvnden helmen die trvegen swert enhant ### an vns wil dienen Rvdeger sine burge vn– siniv lant
###### 2232 | ### Bedaz der videlære die rede vol sprach ### den gvten marcgraven man vor dem hvse sach ### sinen schilt den gvten sazter fvr den fvoz ### do mvser den gesten versagen dienest vn– grvoz
| ### Der edel marcgrave rief hin vf zehant ### nv wert ivch edeln <rechen> von Burgonden lant ### ir soldet min geniezen ir engeltet leider min ### ê do waren wir gefrivnde nv mvz ich iwer vient sin
###### 2234 | ### Do erschracten dirre mære die nothaften man ### in was der trost enpfallen den si da wanden han ### do mit in wolde striten dem si da warn holt ### si heten doh von vienden vil michel arebeit gedolt
###### 2235 | ### Nvne welle got von himele sprach Gvnther der degen ### daz ir ivch svlt genaden noch an vns bewegen ### vn– der vil grozen triwe der wir doch heten mvot ### ich wil iv des baz getrowen daz ir ez nimmer getvot
###### 2236 | ### Ine mages niht gelazen sprach do der chvene man ### ich mvoz mit iv striten wande ihz gelobet han ### nv wert ivch chvnen degene so lieb iv si der lip ### mich enwoldes niht erlazen des [82r]kvnec Ezeln wip
###### 2237 | ### Ir widersaget vns nv ze spate sprach do der chunic her ### nv mvez iv golt vergelten vil edel Rvedeger ### triwe vn– minne die ir vns habt getan ### ob irz an dem ende woldet minneklicher lan
###### 2238 | ### Wir soldenz immer dienen daz ir vns habt gegebn ### ich vn– mine mage ob ir vns liezet leben ### die herlichen gabe do ir vn– iwer man ### vns fvrtet frivntliche zvo dirre hochgezite dan
| ### Wie wol ich iv des gvnde sprach Rvdeger der degen ### daz ich iv mine gabe noch diche solde wegen ### mit vollen willechliche als ich des hete wan ### sone wrde mir dar vmbe nimmer schelten getan
###### 2240 | ### Erwindet edel Rvdeger sprach do Gernot ### wandez wirt deheiner gesten nie erbot ### so rehte minnekliche als ir vns habt getan ### des svlt ir wol geniezen ob wir bi lebene bestan
###### 2241 | ### Daz wolde got sprach Rvdeger vil edel Gernot ### daz ir ze Rine wæret vn– ich wære tot ### mit etelichen eren sit ich ivch sol bestan ### ez enwart noch nie an degenen wirs von frivnden getan
###### 2242 | ### Nv lon iv got her Rvdeger sprach aber Gernot ### die vil richen gabe mich riwet iwer tot ### sol an iv verterben so tvgentlicher mvot ### ich trage hie iwer wafen daz ir mir gabet helet gvot
###### 2243 | ### Daz ist mir nie geswichen in aller dirre not ### vnder sinen ecken lit manic ritter tot ### ez ist lvoter vn– stæte herlich un– gvot ### ich wæn so riche gabe ein reche nimmer mer getvot
###### 2244 | ### Vn– welt ir niht erwinden irn wellet zvo zvns gan ### slaht ir mir iht der frivnde die ich noch hinne han ### mit iwer selbes swerte nim ich iv den lip ### so riwet ir mich Rvdeger vn– herlichez wip
| ### Daz wolde got her Gernot vn– moehte daz ergan ### daz aller iwer wille wære hie getan ### vn– daz genesn wære iwer frivnde lip ### iv sol vil wol getrowen bediv min tohter vn– min wip
###### 2246 | ### Des antwrt im Giselher der edeln voten kint ### wie tvot ir so her Rvdeger die mit mir chomen sint ### si sint iv alle wæge ir grifet vbel zvo ### die iwern schonen tohter welt ir verwitewen ze frvo
###### 2247 | ### Swenne ir vn– iwer rechen mit strite mich bestat ### wie <rehte> vnfrivntliche ir daz schinen lat ### daz ich iv wol getrowe fver ander alle man ### da von ich zeinem wibe iwer tohter mir gewan
###### 2248 | ### Gedenchet iwer triwe vil edel kunich her ### gesende ivch got fon hinnen so sprach Rvdeger ### lat die ivncfrowen niht engelten min ### dvrch aller fvrsten tvgende so rvochet ir genædich sin
###### 2249 | ### Daz tæt ich wol von schulden sprach Giselher daz kint ### die edeln mine mage die noch hier inne sint ### svln die von iv ersterben so mvoz gescheiden [81v]sin ### div vil stæte frivntschaft zvo ziv vn– ovch dem wibe min
| ### Nv mvez vns got genaden sprach do der chvne man ### do hvben si die schilde also si wolden dan ### striten zv den gesten in Chriemh' sal ### do rief vil lvote Hagene von der stiegen hin zetal
###### 2251 | ### Belibet eine wile vil edel Rvdeger ### also sprach do Hagene wir wolden reden mer ### ich vn– mine herren des vns twinget not ### waz mac gefrvmen Ezeln vnser ellenden tot
###### 2252 | ### Ich stan in grozen sorgen vil edel fvrste milt ### mir gab div marcgravinne disen richen schilt ### den habent mir die Hvnen zerhowen vor der hant ### ich fvrt in minneklichen her in Ezelen lant
###### 2253 | ### Daz wolde got von himele sprach aber Hagene ### vnt het ich schilt so gvten hie ze tragene ### also dv hast vor hende vil edel Rvdeger ### sone gerte ich hie zen Hvnen deheiner <halsperge> mer
| ### Vil gern wær ich dir gvot mit mime schilde ### torst ich diren gebieten vor Chriemh' ### doch nim dv in hin Hagene vn– trag in vor der hant ### hey soldestv in fveren in der <Burgonden> lant
###### 2255 | ### Do er im so willechliche den schilt ze gebne bot ### do wart genvger ovgen von weinen harte rot ### ez was div leste gabe die sider immer mer ### gebot deheime degene von Bechelaren Rvdeger
###### 2256 | ### Swie grimme Hagene wære vn– swie herte gemvot ### doch erbarmet in div gabe die der helt gvot ### bi sinen lesten citen so nahe hete getan ### vil manic ritter edele mit im trvren began
###### 2257 | ### Nv lon iv got von himele vil edel Rvdeger ### ez wirt iwer geliche deheiner nimmer mer ### der ellenden rechen so miltechlichen gebe ### got sol daz gebieten daz iwer tvgent immer lebe
###### 2258 | ### Nv lon ich iv der gabe sprach Hagene der degen ### daz ich mich alles vbeles wil gein iv bewegen ### daz nimmer ivch gerveret in strite hie min hant ### ob ir si alle slvget die von Bvrgonden lant
###### 2259 | ### Des neig im do mit zvehten der marcgrave her ### die lvte weinten alle daz disiv starchen ser ### niemen scheiden chvnde daz was ein michel not ### vater aller tvgende lag an Rvdegere tot
###### 2260 | ### Do sprach ovch von dem hvose Volker der spileman ### sit min geselle Hagene den vride hat getan ### den svlt ir also stæte han von miner hant ### daz habt ir wol verdienet do wir chomen in daz lant
###### 2261 | ### Vil edeler marcgrave ir svlt min bote sin ### dise roten bovge gab mir div margravin ### daz ih si tragen solde hie zer hochgecite ### daz han ich geleisten daz ir min zivch des site
| ### Daz wolde got von himele sprach do Rvdeger ### daz iv div marcgravinne noch solde gebn mer ### div mære sage ich gerne der trvtinne min ### vn– gesi[82r]he ich si gesvnde des svlt ir ane zwivel sin
###### 2263 | ### Als er im daz gelobte den schilt hvop Rvdeger ### des mvtes er irtobete dane beit er da niht mer ### er lief vf zv den gesten eiine rechen gelich ### manigen slac vil swinden slvoc der marcgrave rich
###### 2264 | ### Die zwene wichen hoher Volker vn– Hagene ### wandez im ê gelobten die snellen degene ### noch vant er also chvnen bi dem tvrne stan ### daz Rvdeger des strites mit grozen sorgen began
###### 2265 | ### Dvrch mort rêchen willen so liezen si in dar in ### Gvnther vn– Gernot si heten helede sin ### Giselher stvnt vf hoher ze ware ez was im leit ### er versach sich noch des lebenes dar vmbe er Rvdegeren meit
###### 2266 | ### Do sprvngen zvo den vinden des marcgraven man ### man sah si degenliche nach ir herren gan ### div vil scharpfen wafen si trvgen an der hant ### des brast da vil der helme vn– manic herlicher rant
| ### Do slvgen die vil mvden manigen swinden slac ### den von Bechelaren der ebene gelach ### dvrch die liehten ringe vaste vnz vf daz verch ### si frvmten in dem stvrme div vil herlichen werch
###### 2268 | ### Daz edel ingesinde was chomen gar dar in ### Volker vn– Hagene die sprungen balde hin ### sine gaben vride niemen wan dem einem man ### von ir beider hande daz blvot dvrch helme nider ran
###### 2269 | ### Wie rehte gremliche vil swerte drinne erchlanc ### vil der schildes spangen vz den slegen spranch ### des reise ir schiltgesteine verhowen in daz blvot ### si vahten also grimme daz man ez nimmer mer getvot
###### 2270 | ### Der vogt von Bechelaren gie wider vn– dan ### also der mit ellen in stvrme werben chan ### dem tet des tages Rvedeger mit strite wol gelich ### daz er ein degn wære vil <chven> vn– ovch vil lobelich
| ### Hie stvnden dise zwene Gunther vn– Gernot ### si slvogen in dem strite vil manigen helt tot ### Giselher vn– Danchwart die bede ez ringe wach ### des frvmten si vil manigen vnz vf ir ivngesten tach
###### 2272 | ### Wol zeigte der marcgrave daz er was starch genvoc ### chvene vn– wol gewafent hey waz er helde slvoc ### daz sach ein Burgonde do dwang in zornes not ### da von begvnde nahen des gvten Rvdegeres tot
###### 2273 | ### Ez was der starche Gernot den helt den rief er an ### er sprach zem marcgraven ir welt mir miner man ### niht genesen lazen vil edel Rvdeger ### daz mvet mich ane maze ine chans niht an gesehn mer
###### 2274 | ### Nv mag iv iwer gabe wol ze schaden chomen ### sit ir miner frivnde mir habt so vil genomen ### nv wendet ivch her vmbe vil edel chvene man ### iwer gabe wirt verdienet so ich aller hohste kan
###### 2275 | ### E daz der marcgrave vol zvo zim chome dar ### des mvsen liehte ringe werden missevar ### do sprungen zvo [82v]zein ander die ere gernde man ### ir ieteweder schirmen fvr starche wnden im began
| ### Ir swert so scherpfe warn ez enchunde niht gewegen ### do slvoc Gernoten Rvdeger der degen ### dvrch helm vlins herten daz nider vloz daz blvot ### daz vergalt im wol mit ellen der ritter chven vn– gvot
###### 2277 | ### Die Rvdegers gabe an hende er hohe erwach ### swie wnt er zem tode wære er slg im einen slac ### dvrch sinen schilt gvten vnz vf div helm gespan ### da von ersterben mvose der schonen Gotelinde man
###### 2278 | ### lane wart nie wirs gelonet so richer gabe mer ### do vielen bede erslagene die rechen also her ### gelich in dem stvrme von ir selber hant ### alrerst erzvrnede Hagene do er den grozen schaden vant
###### 2279 | ### Do sprach der helt von Tronege ez ist vns vbel chomen ### wir haben an in beiden so <starchen> schaden genomen ### den nimmer vberwindent ir lvte vn– ovch ir lant ### die Rvdegeres degene die mvzen nv sin vnser pfant
###### 2280 | ### Dane wolde ir deheiner dem andern niht vertragen ### vil maniger ane wnden dar nider wart geslagen ### der wol genesen wære ob im wart solch gedranch ### swie gesunt er anders wære der in dem blvot doch ertranch
###### 2281 | ### Owe mines brvder der tot ist hie gefrvomt ### waz wir der leiden mære zallen citen chvomt ### ovch mvz mich immer riwen min sweher Rvdeger ### der schade ist beidenthalben vn– div vil groezlichen ser
| ### Do die rechen sahen daz si beide waren <tot> ### di mvsen liden not ### der tot der svochte sere da sin gesinde was ### der von Bechelaren einer langer niht genas
###### 2283 | ### Gvnther vn– Giselher vn– ovch Hagene ### Danchwart vn– Volker die gvten degene ### die giengen da si fvnden ligen zwene man ### da wart von den heleden mit iamer weinens vil getan
###### 2284 | ### Der tot vns sere rovbet sprach Giselher daz chint ### lazet iwer weinen vn– gen wir an den wint ### daz die ringe erchvelen vns stvrme mvden man ### ia wæn vns <got> niht langer nv daz lebn welle lan
###### 2285 | ### Den sizzen disen leinen sah man da manigen degen ### si waren aber mvzich da waren tot gelegen ### die Rvdegers helde vergangen was der doz ### so lange wert div stille daz sin die kvniginne erdroz
| ### Owe mir dirre swære sprach des kvniges wip ### si sprachent al ze lange vnser viende lip ### mac nv wol vri beliben vor Rvdegeres hant ### er wil si wider bringen heim in der Bvrgonden lant
###### 2287 | ### Waz hilfet chunic Ezele daz wir geteilet han ### mit im swaz er wolde der helt hat missetan ### der vns da solde rechen der wil der svne pflegn ### des antwrt ir Volker der vil zierliche degn
###### 2288 | ### Iane zimt niht reden vbele deheines kvniges wip ### vn– torst ich heizen liegen alsvs edel wip ### so het ir Rvdegere vil vreislich an gelogen ### er vnt die [83r]sinen degene sint an der svne gar betrogen
###### 2289 | ### Er tet so willechliche daz im der kunic gebot ### daz er vn– sine gesinde ist hie gelegen tot ### nv seht alvmbe Chriemh' wem ir nv gebieten welt ### iv hat vnz vf den ende gedienet Rvdeger der helt
###### 2290 | ### Welt ir des niht gelovben man solz ivch sehn lan ### dvrch ir hercenleide so wart daz getan ### man trvoch den helt verhowen da in der kvnic ersach ### den Ezeln degenen so rehteleide nie geschach
###### 2291 | ### Do si den marcgraven sahen toten tragen ### ezn chunde ein schribêre geprieven noch gesagen ### die manigen vngebære der wib vn– man ### von ir hercen swære al da bezeigen began
###### 2292 | ### Do wart der Ezeln iamer so starch vn– also groz ### als eins lewen stimme der riche kunic erdoz ### mit hercen leidem wofe alsam tet ovch sin wip ### si chlageten vngefvge des gvten Rvdegers lip

<<< Übersicht <<< vorige Seite nächste Seite >>>